The informations needed for cluster creation

Name
  An arbitrary human-readable name.
Profile
  Profile used for this cluster.
Min Size
  Min size of the cluster. Default to 0.
Max Size
  Max size of the cluster. Default to -1 means unlimited.
Desired Capacity
  Desired capacity of the cluster. Default to 0.
Timeout
  Cluster creation timeout in seconds.
Metadata
  The metadata yaml used to create the profile.